document.addEventListener('DOMContentLoaded', function() {
    let activeParticle = null;
    
    // Handle paragraph clicks
    document.querySelectorAll('.paragraph').forEach(paragraph => {
        paragraph.addEventListener('click', function() {
            if (activeParticle) {
                activeParticle.classList.remove('active');
            }
            this.classList.add('active');
            activeParticle = this;
        });
    });

    // Handle the Ask button
    const askButton = document.querySelector('.ask-button');
    const textarea = document.querySelector('textarea');
    const responseArea = document.querySelector('.response-area');

    askButton.addEventListener('click', async function() {
        if (!activeParticle) {
            alert('Please select a paragraph first');
            return;
        }

        const question = textarea.value.trim();
        if (!question) {
            alert('Please enter a question');
            return;
        }

        // Show loading state
        responseArea.innerHTML = 'Thinking...';
        askButton.disabled = true;

        try {
            // Here you would normally make an API call to your LLM service
            // This is a mock response for demonstration
            await new Promise(resolve => setTimeout(resolve, 1000));
            
            responseArea.innerHTML = `<div class="response">
                <p><strong>Question:</strong> ${question}</p>
                <p><strong>Context:</strong> ${activeParticle.textContent.substring(0, 100)}...</p>
                <p><strong>Answer:</strong> This is where the LLM response would appear. Connect to your preferred LLM API to get real responses.</p>
            </div>`;
        } catch (error) {
            responseArea.innerHTML = 'Sorry, there was an error processing your request.';
        } finally {
            askButton.disabled = false;
        }
    });

    // Mobile menu toggle
    const menuToggle = document.querySelector('.menu-toggle');
    const sidebar = document.querySelector('.sidebar');

    menuToggle.addEventListener('click', function() {
        sidebar.style.display = sidebar.style.display === 'block' ? 'none' : 'block';
    });

    // Handle window resize
    window.addEventListener('resize', function() {
        if (window.innerWidth > 1024) {
            sidebar.style.display = 'block';
        } else {
            sidebar.style.display = 'none';
        }
    });
});